HISTORY
=======

0.1.2 — 2020-12-01
    The top and bottom nav's content moved around horizontally, based on the
    width of the previous/last page's title. With this revision I made the items
    in the navbar flex items with a fixed width. This fixes certain parts of the
    navbar in place, regardless if the title lengths.

0.1.1 — 2019-09-25
    reduced footer lines from 3 to 2

0.1.0 — 2019-09-25
    initial release
